-- @@stderr --
dtrace: failed to compile script test/unittest/printa/err.D_PRINTF_ARG_TYPE.stack.d: [D_PRINTF_ARG_TYPE] line 12: printa( ) argument #2 is incompatible with conversion #1 prototype:
	conversion: %p
	 prototype: pointer or integer
	  argument: dt_stack_t
